@@ -1,48 +1,38 @@
-is.number <- function(char) str_detect(char, "[0-9]{1}")
-is.period <- function(char) str_detect(char, "[\\.]{1}")
-is.letter <- function(char) str_detect(char, "[a-zA-Z]{1}")
-
-
-
-
-
-
-
 #' mpoly predicate functions
-#' 
+#'
 #' Various functions to deal with mpoly and mpolyList objects.
-#' 
+#'
 #' @param x object to be tested
 #' @return Vector of logicals.
 #' @name predicates
 #' @examples
-#' 
+#'
 #' p <- mp("5")
 #' is.mpoly(p)
 #' is.constant(p)
-#' 
+#'
 #' is.constant(mp(c("x + 1", "7", "y - 2")))
-#' 
+#'
 #' p <- mp("x + y")
 #' is.mpoly(p)
-#' 
+#'
 #' is.mpolyList(mp(c("x + 1", "y - 1")))
 #'
-#' 
-#' 
+#'
+#'
 #' is.linear(mp("0"))
 #' is.linear(mp("x + 1"))
 #' is.linear(mp("x + y"))
 #' is.linear(mp(c("0", "x + y")))
-#' 
+#'
 #' is.linear(mp("x + x y"))
 #' is.linear(mp(c("x + x y", "x")))
-#' 
-#' 
+#'
+#'
 #' (p <- bernstein(2, 5))
 #' is.mpoly(p)
 #' is.bernstein(p)
-#' 
+#'
 #' (p <- chebyshev(5))
 #' is.mpoly(p)
 #' is.chebyshev(p)
@@ -58,21 +48,17 @@ is.letter <- function(char) str_detect(char, "[a-zA-Z]{1}")
 #' @export
 #' @rdname predicates
 is.constant <- function(x){
-  if(is.mpoly(x) && length(x) == 1 && length(x[[1]]) == 1) return(TRUE)
-  if(is.mpolyList(x)) return(vapply(x, is.constant, logical(1)))
+  if (is.mpoly(x) && length(x) == 1 && length(x[[1]]) == 1) return(TRUE)
+  if (is.mpolyList(x)) return(vapply(x, is.constant, logical(1)))
   FALSE
 }
 
 
 
 
-
-
 #' @export
 #' @rdname predicates
-is.mpoly <- function(x) any(class(x) == "mpoly")
-
-
+is.mpoly <- function(x) inherits(x, "mpoly")
 
 
 
@@ -92,51 +78,31 @@ is.unipoly <- function(x) {
 
 
 
-
-
 #' @export
 #' @rdname predicates
-is.bernstein <- function(x) any(class(x) == "bernstein")
+is.bernstein <- function(x) inherits(x, "bernstein")
 
 
 
 
 #' @export
 #' @rdname predicates
-is.bezier <- function(x) any(class(x) == "bezier")
-
-
+is.bezier <- function(x) inherits(x, "bezier")
 
 
 
 
 #' @export
 #' @rdname predicates
-is.chebyshev <- function(x) any(class(x) == "chebyshev")
-
-
-
-
-
-
+is.chebyshev <- function(x) inherits(x, "chebyshev")
 
 
 
+       
 #' @export
 #' @rdname predicates
-is.mpolyList <- function(x){
-  if(any(class(x) == "mpolyList")){
-    return(TRUE)  
-  } else {
-    return(FALSE)	
-  }
-}
-
-
-
-
-
-
+is.mpolyList <- function(x) inherits(x, "mpolyList")
+  
 
 
 
@@ -149,23 +115,14 @@ is.linear <- function(x){
   if(is.mpolyList(x)) return(vapply(x, is.linear, logical(1)))
   
   all(
-    vapply(x, function(term) all(length(term) <= 2), logical(1))
+    vapply(x, function(term) (length(term) <= 2L) && all(rev(term)[-1] <= 1L), logical(1))
   )  
+  
 }
 
 
 
 
-
-
-
-
-
-
-
-
-
-
 #' Test whether an object is a whole number
 #'
 #' Test whether an object is a whole number.
@@ -176,7 +133,7 @@ is.linear <- function(x){
 #' @export
 #' @examples
 #' is.wholenumber(seq(-3,3,.5))
-is.wholenumber <- function(x, tol = .Machine$double.eps^0.5){
+is.wholenumber <- function (x, tol = .Machine$double.eps^0.5){
   abs(x - round(x)) < tol
 }
 
